@@ -1,7 +1,7 @@
 # #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 # <HTTPretty - HTTP client mock for Python>
-# Copyright (C) <2011-2013>  Gabriel Falcão <gabriel@nacaolivre.org>
+# Copyright (C) <2011-2018>  Gabriel Falcao <gabriel@nacaolivre.org>
 #
 # Permission is hereby granted, free of charge, to any person
 # obtaining a copy of this software and associated documentation
@@ -23,17 +23,29 @@
 # WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 # FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 # OTHER DEALINGS IN THE SOFTWARE.
-from __future__ import unicode_literals
+# flake8: noqa
 
-__version__ = version = '0.8.10'
-
-from .core import httpretty, httprettified, EmptyRequestHeaders
+from . import core
 from .errors import HTTPrettyError, UnmockedError
-from .core import URIInfo
+from .version import version
+
+__version__ = version
+
+# aliases
+EmptyRequestHeaders = core.EmptyRequestHeaders
+Entry = core.Entry
+HTTPrettyRequestEmpty = core.HTTPrettyRequestEmpty
+URIInfo = core.URIInfo
+URIMatcher = core.URIMatcher
+httprettified = core.httprettified
+httprettized = core.httprettized
+httpretty = core.httpretty
 
 HTTPretty = httpretty
 activate = httprettified
 
+enabled = httprettized
+
 enable = httpretty.enable
 register_uri = httpretty.register_uri
 disable = httpretty.disable
@@ -52,9 +64,19 @@ CONNECT = httpretty.CONNECT
 
 
 def last_request():
-    """returns the last request"""
+    """
+    :returns: the last :py:class:`~httpretty.core.HTTPrettyRequest`
+    """
     return httpretty.last_request
 
+
+def latest_requests():
+    """returns the history of made requests"""
+    return httpretty.latest_requests
+
+
 def has_request():
-    """returns a boolean indicating whether any request has been made"""
+    """
+    :returns: bool - whether any request has been made
+    """
     return not isinstance(httpretty.last_request.headers, EmptyRequestHeaders)
